Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/edwh_files_plugin/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
src/edwh_files_plugin/compression.py | Compression | 44 | 15 | 0 | 16 | 2 | 72%
src/edwh_files_plugin/compression.py | Nocompression | 19 | 2 | 0 | 10 | 2 | 86%
src/edwh_files_plugin/compression.py | Zip | 38 | 7 | 0 | 20 | 6 | 78%
src/edwh_files_plugin/compression.py | Gzip | 34 | 6 | 0 | 8 | 2 | 81%
src/edwh_files_plugin/compression.py | Pigz | 13 | 4 | 0 | 4 | 2 | 65%
src/edwh_files_plugin/compression.py | (no class) | 69 | 3 | 0 | 0 | 0 | 96%
src/edwh_files_plugin/files_plugin.py | (no class) | 111 | 111 | 0 | 30 | 0 | 0%
tests/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_compression.py | test_noop.Noop | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_compression.py | (no class) | 112 | 0 | 0 | 2 | 0 | 100%
Total |  | 440 | 148 | 0 | 90 | 14 | 64%

No items found using the specified filter.